========
GodSpeed
========


.. image:: https://img.shields.io/pypi/v/godspeed.svg
        :target: https://pypi.python.org/pypi/godspeed

.. image:: https://readthedocs.org/projects/godspeed/badge/?version=latest
        :target: https://godspeed.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Python Boilerplate Project contains all the boilerplate you need to create a Python package.


* Free software: GNU General Public License v3
* Documentation: https://godspeed.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `cogsys-io/cogsys-io-cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/cookiecutter/cookiecutter
.. _`cogsys-io/cogsys-io-cookiecutter-pypackage`: https://github.com/cogsys-io/cogsys-io-cookiecutter-pypackage
